summaryrefslogtreecommitdiffhomepage
path: root/examples
diff options
context:
space:
mode:
authorRay <[email protected]>2021-03-25 13:41:32 +0100
committerRay <[email protected]>2021-03-25 13:41:32 +0100
commitdd5935048539486b0672d8cf112f3df806352dea (patch)
tree8e9d22492c5fe9abc9d6b90ee0c94970e509059c /examples
parent7e588388952c7d8fc5e080d204be33af56ffc55a (diff)
downloadraylib-dd5935048539486b0672d8cf112f3df806352dea.tar.gz
raylib-dd5935048539486b0672d8cf112f3df806352dea.zip
REVIEW: instancing example formating
Diffstat (limited to 'examples')
-rw-r--r--examples/shaders/shaders_rlgl_mesh_instanced.c128
1 files changed, 64 insertions, 64 deletions
diff --git a/examples/shaders/shaders_rlgl_mesh_instanced.c b/examples/shaders/shaders_rlgl_mesh_instanced.c
index b76a1c56..3477b0cf 100644
--- a/examples/shaders/shaders_rlgl_mesh_instanced.c
+++ b/examples/shaders/shaders_rlgl_mesh_instanced.c
@@ -22,12 +22,13 @@
#include "rlights.h"
#include <stdlib.h>
+#include <math.h>
-#define GLSL_VERSION 330
-
-float maxf(float a, float b){
- return (a > b ? a : b);
-}
+#if defined(PLATFORM_DESKTOP)
+ #define GLSL_VERSION 330
+#else // PLATFORM_RPI, PLATFORM_ANDROID, PLATFORM_WEB
+ #define GLSL_VERSION 100
+#endif
//------------------------------------------------------------------------------------
// Program main entry point
@@ -38,17 +39,18 @@ int main(void)
//--------------------------------------------------------------------------------------
const int screenWidth = 800;
const int screenHeight = 450;
- int speed = 30; // speed of jump animation
- int groups = 2; // count of separate groups jumping around
- float amp = 10; // maximum amplitude of jump
- float variance = 0.8; // global variance in jump height
- float loop=0; // individual cube's computed loop timer .
- float x=0,y=0,z=0; // used for various 3D coordinate & vector ops.
const int fps = 60;
SetConfigFlags(FLAG_MSAA_4X_HINT); // Enable Multi Sampling Anti Aliasing 4x (if available)
InitWindow(screenWidth, screenHeight, "raylib [shaders] example - rlgl mesh instanced");
+ int speed = 30; // Speed of jump animation
+ int groups = 2; // Count of separate groups jumping around
+ float amp = 10; // Maximum amplitude of jump
+ float variance = 0.8f; // Global variance in jump height
+ float loop = 0.0f; // Individual cube's computed loop timer
+ float x = 0.0f, y = 0.0f, z = 0.0f; // Used for various 3D coordinate & vector ops
+
// Define the camera to look into our 3d world
Camera camera = { 0 };
camera.position = (Vector3){ -125.0f, 125.0f, -125.0f };
@@ -75,8 +77,8 @@ int main(void)
x = GetRandomValue(0, 360);
y = GetRandomValue(0, 360);
z = GetRandomValue(0, 360);
- Vector3 axis = Vector3Normalize((Vector3){x, y, z});
- float angle = (float)GetRandomValue(0, 10) * DEG2RAD;
+ Vector3 axis = Vector3Normalize((Vector3){ x, y, z });
+ float angle = (float)GetRandomValue(0, 10)*DEG2RAD;
rotationsInc[i] = MatrixRotate(axis, angle);
rotations[i] = MatrixIdentity();
@@ -96,33 +98,34 @@ int main(void)
int ambientLoc = GetShaderLocation(shader, "ambient");
SetShaderValue(shader, ambientLoc, (float[4]){ 0.2f, 0.2f, 0.2f, 1.0f }, SHADER_UNIFORM_VEC4);
- CreateLight(LIGHT_DIRECTIONAL, (Vector3){ 50, 50, 0 }, Vector3Zero(), WHITE, shader);
+ CreateLight(LIGHT_DIRECTIONAL, (Vector3){ 50.0f, 50.0f, 0.0f }, Vector3Zero(), WHITE, shader);
Material material = LoadMaterialDefault();
material.shader = shader;
material.maps[MATERIAL_MAP_DIFFUSE].color = RED;
- SetCameraMode(camera, CAMERA_ORBITAL); // Set a free camera mode
+ SetCameraMode(camera, CAMERA_ORBITAL); // Set an orbital camera mode
+
+ int textPositionY = 300;
+
+ int framesCounter = 0; // Simple frames counter to manage animation
SetTargetFPS(fps); // Set our game to run at 60 frames-per-second
//--------------------------------------------------------------------------------------
// Main game loop
- int frame = 0; // simple frame counter to manage animation
while (!WindowShouldClose()) // Detect window close button or ESC key
{
// Update
//----------------------------------------------------------------------------------
UpdateCamera(&camera);
- frame ++;
-
- //if (IsKeyDown(KEY_RIGHT)) ballPosition.x += 2.0f;
- //if (IsKeyDown(KEY_LEFT)) ballPosition.x -= 2.0f;
- if (IsKeyDown(KEY_UP)) amp += 0.5;
- if (IsKeyDown(KEY_DOWN)) amp = amp <= 1 ? 1 : amp - 1.0;
- if (IsKeyDown(KEY_LEFT)) variance = variance <=0 ? 0 : variance - 0.01;
- if (IsKeyDown(KEY_RIGHT)) variance = variance >=1 ? 1 : variance + 0.01;
+ framesCounter++;
+
+ if (IsKeyDown(KEY_UP)) amp += 0.5f;
+ if (IsKeyDown(KEY_DOWN)) amp = (amp <= 1)? 1.0f : (amp - 1.0f);
+ if (IsKeyDown(KEY_LEFT)) variance = (variance <= 0.0f)? 0.0f : (variance - 0.01f);
+ if (IsKeyDown(KEY_RIGHT)) variance = (variance >= 1.0f)? 1.0f : (variance + 0.01f);
if (IsKeyDown(KEY_ONE)) groups = 1;
if (IsKeyDown(KEY_TWO)) groups = 2;
if (IsKeyDown(KEY_THREE)) groups = 3;
@@ -132,34 +135,34 @@ int main(void)
if (IsKeyDown(KEY_SEVEN)) groups = 7;
if (IsKeyDown(KEY_EIGHT)) groups = 8;
if (IsKeyDown(KEY_NINE)) groups = 9;
- if (IsKeyDown(KEY_W)) {groups=7; amp = 25; speed=18; variance=0.70;}
+ if (IsKeyDown(KEY_W)) { groups = 7; amp = 25; speed = 18; variance = 0.70f; }
- if (IsKeyDown(KEY_EQUAL)) speed = speed <= (fps *.25) ? (fps *.25) : speed * 0.95;
- if (IsKeyDown(KEY_KP_ADD)) speed = speed <= (fps *.25) ? (fps *.25) : speed * 0.95;
+ if (IsKeyDown(KEY_EQUAL)) speed = (speed <= (fps*0.25f))? (fps*0.25f) : (speed*0.95f);
+ if (IsKeyDown(KEY_KP_ADD)) speed = (speed <= (fps*0.25f))? (fps*0.25f) : (speed*0.95f);
- if (IsKeyDown(KEY_MINUS)) speed = maxf(speed * 1.02, speed + 1) ;
- if (IsKeyDown(KEY_KP_SUBTRACT)) maxf(speed * 1.02, speed + 1) ;
-
+ if (IsKeyDown(KEY_MINUS)) speed = fmaxf(speed*1.02f, speed + 1);
+ if (IsKeyDown(KEY_KP_SUBTRACT)) speed = fmaxf(speed*1.02f, speed + 1);
// Update the light shader with the camera view position
float cameraPos[3] = { camera.position.x, camera.position.y, camera.position.z };
SetShaderValue(shader, shader.locs[SHADER_LOC_VECTOR_VIEW], cameraPos, SHADER_UNIFORM_VEC3);
// Apply per-instance transformations
- for (int i = 0; i < count; i++){
+ for (int i = 0; i < count; i++)
+ {
rotations[i] = MatrixMultiply(rotations[i], rotationsInc[i]);
transforms[i] = MatrixMultiply(rotations[i], translations[i]);
- // get the animation cycle's frame for this instance.
- loop = (float)( (frame + (int)(((float)(i % groups)/groups) * speed)) % speed) / speed;
+ // Get the animation cycle's framesCounter for this instance
+ loop = (float)((framesCounter + (int)(((float)(i%groups)/groups)*speed))%speed)/speed;
- // calculate the y according to loop cycle
- y = ( sinf( loop * PI * 2 ) ) * (amp )* ((1 - variance) + ((variance) * (float)(i % (groups * 10)) / (groups * 10)));
+ // Calculate the y according to loop cycle
+ y = (sinf(loop*PI*2))*amp*((1 - variance) + (variance*(float)(i%(groups*10))/(groups*10)));
- // clamp to floor
- y = (y<0 ? 0 : y);
+ // Clamp to floor
+ y = (y < 0)? 0.0f : y;
- transforms[i] = MatrixMultiply(transforms[i], MatrixTranslate(0, y, 0));
+ transforms[i] = MatrixMultiply(transforms[i], MatrixTranslate(0.0f, y, 0.0f));
}
//----------------------------------------------------------------------------------
@@ -170,42 +173,39 @@ int main(void)
ClearBackground(RAYWHITE);
BeginMode3D(camera);
- rlDrawMeshInstanced(cube, material, transforms, count);
+ DrawMeshInstanced(cube, material, transforms, count);
EndMode3D();
- int u = 10;
- int u2 = u + 40;
- int u3 = u2 + 110;
- int v = 300;
+
DrawText("A CUBE OF DANCING CUBES!", 490, 10, 20, MAROON);
- DrawText("PRESS KEYS:", u, v, 20, BLACK);
+ DrawText("PRESS KEYS:", 10, textPositionY, 20, BLACK);
- DrawText("1 - 9", u, v+=25, 10, BLACK);
- DrawText(": Number of groups", u2, v , 10, BLACK);
- DrawText(TextFormat(": %d", groups), u3, v , 10, BLACK);
+ DrawText("1 - 9", 10, textPositionY += 25, 10, BLACK);
+ DrawText(": Number of groups", 50, textPositionY , 10, BLACK);
+ DrawText(TextFormat(": %d", groups), 160, textPositionY , 10, BLACK);
- DrawText("UP", u, v+=15, 10, BLACK);
- DrawText(": increase amplitude", u2, v, 10, BLACK);
- DrawText(TextFormat(": %.2f", amp), u3, v , 10, BLACK);
+ DrawText("UP", 10, textPositionY += 15, 10, BLACK);
+ DrawText(": increase amplitude", 50, textPositionY, 10, BLACK);
+ DrawText(TextFormat(": %.2f", amp), 160, textPositionY , 10, BLACK);
- DrawText("DOWN", u, v+=15, 10, BLACK);
- DrawText(": decrease amplitude", u2, v, 10, BLACK);
+ DrawText("DOWN", 10, textPositionY += 15, 10, BLACK);
+ DrawText(": decrease amplitude", 50, textPositionY, 10, BLACK);
- DrawText("LEFT", u, v+=15, 10, BLACK);
- DrawText(": decrease variance", u2, v, 10, BLACK);
- DrawText(TextFormat(": %.2f", variance), u3, v , 10, BLACK);
+ DrawText("LEFT", 10, textPositionY += 15, 10, BLACK);
+ DrawText(": decrease variance", 50, textPositionY, 10, BLACK);
+ DrawText(TextFormat(": %.2f", variance), 160, textPositionY , 10, BLACK);
- DrawText("RIGHT", u, v+=15, 10, BLACK);
- DrawText(": increase variance", u2, v, 10, BLACK);
+ DrawText("RIGHT", 10, textPositionY += 15, 10, BLACK);
+ DrawText(": increase variance", 50, textPositionY, 10, BLACK);
- DrawText("+/=", u, v+=15, 10, BLACK);
- DrawText(": increase speed", u2, v, 10, BLACK);
- DrawText(TextFormat(": %d = %f loops/sec", speed, ((float)fps / speed)), u3, v , 10, BLACK);
+ DrawText("+/=", 10, textPositionY += 15, 10, BLACK);
+ DrawText(": increase speed", 50, textPositionY, 10, BLACK);
+ DrawText(TextFormat(": %d = %f loops/sec", speed, ((float)fps / speed)), 160, textPositionY , 10, BLACK);
- DrawText("-", u, v+=15, 10, BLACK);
- DrawText(": decrease speed", u2, v, 10, BLACK);
+ DrawText("-", 10, textPositionY += 15, 10, BLACK);
+ DrawText(": decrease speed", 50, textPositionY, 10, BLACK);
- DrawText("W", u, v+=15, 10, BLACK);
- DrawText(": Wild setup!", u2, v, 10, BLACK);
+ DrawText("W", 10, textPositionY += 15, 10, BLACK);
+ DrawText(": Wild setup!", 50, textPositionY, 10, BLACK);
DrawFPS(10, 10);